@@ -25,22 +25,27 @@ from ._gi import _API, Repository
 # Force loading the GObject typelib so we have available the wrappers for
 # base classes such as GInitiallyUnowned
 import gi._gobject
+gi  # pyflakes
+
+_API = _API  # pyflakes
+
 import os
 
 _versions = {}
 _overridesdir = os.path.join(os.path.dirname(__file__), 'overrides')
 
+
 def require_version(namespace, version):
     repository = Repository.get_default()
 
     if namespace in repository.get_loaded_namespaces():
         loaded_version = repository.get_version(namespace)
         if loaded_version != version:
-            raise ValueError('Namespace %s is already loaded with version %s' % \
+            raise ValueError('Namespace %s is already loaded with version %s' %
                              (namespace, loaded_version))
 
     if namespace in _versions and _versions[namespace] != version:
-        raise ValueError('Namespace %s already requires version %s' % \
+        raise ValueError('Namespace %s already requires version %s' %
                          (namespace, _versions[namespace]))
 
     available_versions = repository.enumerate_versions(namespace)
@@ -48,10 +53,11 @@ def require_version(namespace, version):
         raise ValueError('Namespace %s not available' % namespace)
 
     if version not in available_versions:
-        raise ValueError('Namespace %s not available for version %s' % \
+        raise ValueError('Namespace %s not available for version %s' %
                          (namespace, version))
 
     _versions[namespace] = version
 
+
 def get_required_version(namespace):
     return _versions.get(namespace, None)
