@@ -334,7 +334,10 @@ __all__.append('SizeGroup')
 
 class MenuItem(Gtk.MenuItem):
     def __init__(self, label=None, **kwds):
-        super(MenuItem, self).__init__(label=label, **kwds)
+        if label:
+            super(MenuItem, self).__init__(label=label, **kwds)
+        else:
+            super(MenuItem, self).__init__(**kwds)
 
 MenuItem = override(MenuItem)
 __all__.append('MenuItem')
@@ -1226,6 +1229,9 @@ class TreePath(Gtk.TreePath):
     def __iter__(self):
         return (int(part) for part in str(self).split(':'))
 
+    def __len__(self):
+        return self.get_depth()
+
 TreePath = override(TreePath)
 __all__.append('TreePath')
 
