@@ -464,6 +464,11 @@ class TestGLib(unittest.TestCase):
         assert_equals_bool('v', GLib.Variant('i', 0))
         assert_equals_bool('v', GLib.Variant('i', 1))
 
+    def test_variant_repr(self):
+        v = GLib.Variant('(is)', (1, 'somestring'))
+        self.assertEqual(str(v), "(1, 'somestring')")
+        self.assertEqual(repr(v), "GLib.Variant('(is)', (1, 'somestring'))")
+
 
 class TestPango(unittest.TestCase):
 
@@ -1364,18 +1369,22 @@ class TestGtk(unittest.TestCase):
         p2 = Gtk.TreePath.new_first()
         self.assertEqual(p1, p2)
         self.assertEqual(str(p1), '0')
+        self.assertEqual(len(p1), 1)
         p1 = Gtk.TreePath(2)
         p2 = Gtk.TreePath.new_from_string('2')
         self.assertEqual(p1, p2)
         self.assertEqual(str(p1), '2')
+        self.assertEqual(len(p1), 1)
         p1 = Gtk.TreePath('1:2:3')
         p2 = Gtk.TreePath.new_from_string('1:2:3')
         self.assertEqual(p1, p2)
         self.assertEqual(str(p1), '1:2:3')
+        self.assertEqual(len(p1), 3)
         p1 = Gtk.TreePath((1, 2, 3))
         p2 = Gtk.TreePath.new_from_string('1:2:3')
         self.assertEqual(p1, p2)
         self.assertEqual(str(p1), '1:2:3')
+        self.assertEqual(len(p1), 3)
         self.assertNotEqual(p1, None)
         self.assertTrue(p1 > None)
         self.assertTrue(p1 >= None)
